# Tapioca Harvest

## Installation
```
pip install tapioca-harvest
```

## Documentation
``` python
from tapioca_harvest import Harvest


api = Harvest(
    token='{YOUR_HARVEST_API_TOKEN}',
    account_id='{YOUR_HARVEST_ACCOUNT_ID}',
    user_agent='{YOUR_HARVEST_APP_NAME}'
)

```

No more documentation needed.

- Learn how Tapioca works [here](http://tapioca-wrapper.readthedocs.org/en/stable/quickstart.html)
- Explore this package using iPython
- Have fun!
